@@ -413,7 +413,11 @@ class UiSchemaProcessor(ProcessingMixin):
         ]
         if custom_validators:
             result['ui:custom-validators'] = [
-                {'code': v.code, 'message': v.message} for v in custom_validators
+                {
+                    'code': getattr(v, 'code', v.__class__.__name__.lower()),
+                    'message': getattr(v, 'message'),
+                }
+                for v in custom_validators
             ]
 
         return result
